==> django-lookup-table-rating-widget-0.1.0.tar.gz: django-lookup-table-rating-widget-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = fobj.readlines()
requires = [x.strip() for x in requires if x.strip()]

setup(
    name="django-lookup-table-rating-widget",
    version="0.1.0",
    description="A django rating widget with a lookup-table for score-making rules.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django lookup table rating widget"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_lookup_table_rating_widget_example", "django_lookup_table_rating_widget_example.migrations", "django_lookup_table_rating_widget_demo"]),
    py_modules=["django_lookup_table_rating_widget"],
    zip_safe=False,
    include_package_data=True,
)

==> django-lookup-table-rating-widget-0.1.1.tar.gz: django-lookup-table-rating-widget-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-lookup-table-rating-widget",
    version="0.1.1",
    description="A django rating widget with a lookup-table for score-making rules.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    url="https://github.com/zencore-cn/zencore-issues",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django lookup table rating widget"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_lookup_table_rating_widget_example", "django_lookup_table_rating_widget_example.migrations", "django_lookup_table_rating_widget_demo"]),
    zip_safe=False,
    include_package_data=True,
)
